@@ -5,7 +5,7 @@ from django.core.exceptions import ImproperlyConfigured
 
 if conf.API_KEY and conf.API_SECRET:
     stream_client = stream.connect(
-        conf.API_KEY, conf.API_SECRET)
+        conf.API_KEY, conf.API_SECRET, location=conf.LOCATION)
 else:
     stream_client = stream.connect()
 
