@@ -1,8 +1,9 @@
+import django
 from django.conf import settings
 
-
 API_KEY = getattr(settings, 'STREAM_API_KEY', None)
 API_SECRET = getattr(settings, 'STREAM_API_SECRET', None)
+LOCATION = getattr(settings, 'STREAM_LOCATION', None)
 
 FEED_MANAGER_CLASS = getattr(settings, 'STREAM_FEED_MANAGER_CLASS',
     'stream_django.managers.FeedManager'
@@ -15,3 +16,5 @@ NEWS_FEEDS = getattr(settings, 'STREAM_NEWS_FEEDS',
 NOTIFICATION_FEED = getattr(settings, 'STREAM_PERSONAL_FEED', 'notification')
 
 DISABLE_MODEL_TRACKING = getattr(settings, 'STREAM_DISABLE_MODEL_TRACKING', False)
+
+DJANGO_MAJOR_VERSION = django.VERSION[0] + (0.1*django.VERSION[1])
