@@ -17,7 +17,7 @@ class EnrichedActivity(collections.MutableMapping):
 
     def __init__(self, activity_data):
         self.activity_data = activity_data
-        self.not_enriched_fields = []
+        self.not_enriched_data = {}
 
     def __getitem__(self, key):
         return self.activity_data[self.__keytransform__(key)]
@@ -37,11 +37,12 @@ class EnrichedActivity(collections.MutableMapping):
     def __keytransform__(self, key):
         return key
 
-    def track_not_enriched_fields(self, field):
-        self.not_enriched_fields.append(field)
+    def track_not_enriched_field(self, field, value):
+        self.not_enriched_data[field] = value
 
+    @property
     def enriched(self):
-        len(self.not_enriched_fields) == 0
+        return len(self.not_enriched_data.keys()) == 0
 
 
 class Enrich(object):
@@ -69,13 +70,13 @@ class Enrich(object):
     def wrap_activities(self, activities):
         return [EnrichedActivity(a) for a in activities]
 
-    def is_ref(activity, field):
-        return (activity.get('field', '').split(':') == 2)
+    def is_ref(self, activity, field):
+        return (len(activity.get(field, '').split(':')) == 2)
 
     def _collect_references(self, activities, fields):
         model_references = defaultdict(list)
         for activity, field in itertools.product(activities, fields):
-            if self.is_ref(activity, field):
+            if not self.is_ref(activity, field):
                 continue
             f_ct, f_id = activity[field].split(':')
             model_references[f_ct].append(f_id)
@@ -90,8 +91,8 @@ class Enrich(object):
         if hasattr(self, hook_function_name):
             return getattr(self, hook_function_name)(pks)
         qs = modelClass.objects
-        if hasattr(modelClass, 'related_models') and modelClass.related_models() is not None:
-            qs = qs.select_related(*modelClass.related_models())
+        if hasattr(modelClass, 'activity_related_models') and modelClass.activity_related_models() is not None:
+            qs = qs.select_related(*modelClass.activity_related_models())
         return qs.in_bulk(pks)
 
     def _fetch_objects(self, references):
@@ -104,16 +105,12 @@ class Enrich(object):
         return objects
 
     def _inject_objects(self, activities, objects, fields):
-        not_enriched = []
         for activity, field in itertools.product(activities, fields):
             if not self.is_ref(activity, field):
                 continue
             f_ct, f_id = activity[field].split(':')
             instance = objects[f_ct].get(int(f_id))
             if instance is None:
-                not_enriched.append(activity, field)
+                activity.track_not_enriched_field(field, activity[field])
             else:
                 activity[field] = instance
-
-        for activity, field in not_enriched:
-            activity.track_not_enriched_fields(field)
